@@ -1,17 +1,46 @@
-/* mips-stub.c - helper functions for stub, generic to all MIPS processors
- * 
- * Copyright (c) 1998,1999 Cygnus Solutions
- *
- * The authors hereby grant permission to use, copy, modify, distribute,
- * and license this software and its documentation for any purpose, provided
- * that existing copyright notices are retained in all copies and that this
- * notice is included verbatim in any distributions. No written agreement,
- * license, or royalty fee is required for any of the authorized uses.
- * Modifications to this software may be copyrighted by their authors
- * and need not follow the licensing terms described here, provided that
- * the new terms are clearly indicated on the first page of each file where
- * they apply.
- */
+//========================================================================
+//
+//      mips-stub.h
+//
+//      Helper functions for stub, generic to all MIPS processors
+//
+//========================================================================
+//####COPYRIGHTBEGIN####
+//                                                                          
+// -------------------------------------------                              
+// The contents of this file are subject to the Red Hat eCos Public License 
+// Version 1.1 (the "License"); you may not use this file except in         
+// compliance with the License.  You may obtain a copy of the License at    
+// http://www.redhat.com/                                                   
+//                                                                          
+// Software distributed under the License is distributed on an "AS IS"      
+// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
+// License for the specific language governing rights and limitations under 
+// the License.                                                             
+//                                                                          
+// The Original Code is eCos - Embedded Configurable Operating System,      
+// released September 30, 1998.                                             
+//                                                                          
+// The Initial Developer of the Original Code is Red Hat.                   
+// Portions created by Red Hat are                                          
+// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
+// All Rights Reserved.                                                     
+// -------------------------------------------                              
+//                                                                          
+//####COPYRIGHTEND####
+//========================================================================
+//#####DESCRIPTIONBEGIN####
+//
+// Author(s):     Red Hat, nickg
+// Contributors:  Red Hat, nickg
+// Date:          1998-06-08
+// Purpose:       
+// Description:   Helper functions for stub, generic to all MIPS processors
+// Usage:         
+//
+//####DESCRIPTIONEND####
+//
+//========================================================================
 
 #include <stddef.h>
 
@@ -27,6 +56,50 @@
 #include <cyg/hal/hal_arch.h>
 #include <cyg/hal/mips_opcode.h>
 
+typedef unsigned long t_inst;
+
+/*----------------------------------------------------------------------
+ * Asynchronous interrupt support
+ */
+
+static struct
+{
+  t_inst *targetAddr;
+  t_inst savedInstr;
+} asyncBuffer;
+
+/* Called to asynchronously interrupt a running program.
+   Must be passed address of instruction interrupted.
+   This is typically called in response to a debug port
+   receive interrupt.
+*/
+
+void
+install_async_breakpoint(void *epc)
+{
+  long gp_save;
+
+  /* This may be called from a separately linked program,
+     so we need to save and restore the incoming gp register
+     and setup our stub local gp register. 
+     Alternatively, we could skip this foolishness if we
+     compiled libstub with "-G 0". */
+
+  __asm__ volatile ( "move   %0,$28\n"
+		     ".extern _gp\n"
+		     "la     $28,_gp\n"
+		     : "=r" (gp_save) );
+
+  asyncBuffer.targetAddr = epc;
+  asyncBuffer.savedInstr = *(t_inst *)epc;
+  *(t_inst *)epc = *(t_inst *)_breakinst;
+  __instruction_cache(CACHE_FLUSH);
+  __data_cache(CACHE_FLUSH);
+
+  __asm__  volatile ( "move   $28,%0\n" :: "r"(gp_save) );
+}
+
+/*--------------------------------------------------------------------*/
 /* Given a trap value TRAP, return the corresponding signal. */
 
 int __computeSignal (unsigned int trap_number)
@@ -45,6 +118,15 @@ int __computeSignal (unsigned int trap_number)
 
     case EXC_BP:
       /* Break point */
+      if (asyncBuffer.targetAddr != NULL)
+	{
+	  /* BP installed by serial driver to stop running program */
+	  *asyncBuffer.targetAddr = asyncBuffer.savedInstr;
+          __instruction_cache(CACHE_FLUSH);
+          __data_cache(CACHE_FLUSH);
+	  asyncBuffer.targetAddr = NULL;
+	  return SIGINT;
+	}
       return SIGTRAP;
 
     case EXC_OVF:
@@ -104,8 +186,6 @@ void set_pc (target_register_t pc)
 
 /* Saved instruction data for single step support.  */
 
-typedef unsigned long t_inst;
-
 static struct
 {
   t_inst *targetAddr;
@@ -144,7 +224,7 @@ void __single_step (void)
         case OP_BLTZL:
         case OP_BLTZAL:
         case OP_BLTZALL:
-          if (get_register (inst.IType.rs) < 0 )
+            if ((int)get_register (inst.IType.rs) < 0 )
             instrBuffer.targetAddr =
               (t_inst *)(((signed short)inst.IType.imm<<2)
                                         + (get_register (PC) + 4));
@@ -155,7 +235,7 @@ void __single_step (void)
         case OP_BGEZL:
         case OP_BGEZAL:
         case OP_BGEZALL:
-          if (get_register (inst.IType.rs) >= 0 )
+            if ((int)get_register (inst.IType.rs) >= 0 )
             instrBuffer.targetAddr =
               (t_inst *)(((signed short)inst.IType.imm<<2)
                                         + (get_register (PC) + 4));
@@ -192,7 +272,7 @@ void __single_step (void)
       break;
     case OP_BLEZ:
     case OP_BLEZL:
-      if (get_register (inst.IType.rs) <= 0)
+        if ((int)get_register (inst.IType.rs) <= 0)
         instrBuffer.targetAddr =
           (t_inst *)(((signed short)inst.IType.imm<<2) + (get_register (PC) + 4));
       else
@@ -200,20 +280,21 @@ void __single_step (void)
       break;
     case OP_BGTZ:
     case OP_BGTZL:
-      if (get_register (inst.IType.rs) > 0)
+        if ((int)get_register (inst.IType.rs) > 0)
         instrBuffer.targetAddr =
           (t_inst *)(((signed short)inst.IType.imm<<2) + (get_register (PC) + 4));
       else
         instrBuffer.targetAddr = (t_inst *)(get_register (PC) + 8);
       break;
 
-#if 0   /* no floating point support at the moment */
+#ifdef CYGHWR_HAL_MIPS_FPU
+
     case OP_COP1:
       if (inst.RType.rs == OP_BC)
           switch (inst.RType.rt) {
             case COPz_BCF:
             case COPz_BCFL:
-              if (get_register (FCSR) & CSR_C)
+                if (get_register (FCR31) & FCR31_C)
                 instrBuffer.targetAddr = (t_inst *)(get_register (PC) + 8);
               else
                 instrBuffer.targetAddr =
@@ -222,7 +303,7 @@ void __single_step (void)
               break;
             case COPz_BCT:
             case COPz_BCTL:
-              if (get_register (FCSR) & CSR_C)
+                if (get_register (FCR31) & FCR31_C)
                 instrBuffer.targetAddr =
                   (t_inst *)(((signed short)inst.IType.imm<<2)
                                             + (get_register (PC) + 4));
@@ -260,6 +341,12 @@ void __install_breakpoints ()
       *instrBuffer.targetAddr = __break_opcode ();
 //diag_printf("ta %08x si %08x *ta %08x\n",
 //            instrBuffer.targetAddr,instrBuffer.savedInstr,*instrBuffer.targetAddr);
+
+      /* Ensure that the planted breakpoint makes it out to memory and
+         is subsequently loaded into the instruction cache.
+      */
+      __data_cache (CACHE_FLUSH) ;
+      __instruction_cache (CACHE_FLUSH) ;
     }
 }
 
@@ -274,7 +361,7 @@ void __clear_breakpoints (void)
 int
 __is_breakpoint_function ()
 {
-    return get_register (PC) == (target_register_t)&CYG_LABEL_NAME(breakinst);
+    return get_register (PC) == (target_register_t)(unsigned long)&CYG_LABEL_NAME(breakinst);
 }
 
 
