@@ -6,25 +6,27 @@
 //
 //=============================================================================
 //####COPYRIGHTBEGIN####
-//
-// -------------------------------------------
-// The contents of this file are subject to the Cygnus eCos Public License
-// Version 1.0 (the "License"); you may not use this file except in
-// compliance with the License.  You may obtain a copy of the License at
-// http://sourceware.cygnus.com/ecos
-// 
-// Software distributed under the License is distributed on an "AS IS"
-// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the
-// License for the specific language governing rights and limitations under
-// the License.
-// 
-// The Original Code is eCos - Embedded Cygnus Operating System, released
-// September 30, 1998.
-// 
-// The Initial Developer of the Original Code is Cygnus.  Portions created
-// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
-// -------------------------------------------
-//
+//                                                                          
+// -------------------------------------------                              
+// The contents of this file are subject to the Red Hat eCos Public License 
+// Version 1.1 (the "License"); you may not use this file except in         
+// compliance with the License.  You may obtain a copy of the License at    
+// http://www.redhat.com/                                                   
+//                                                                          
+// Software distributed under the License is distributed on an "AS IS"      
+// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
+// License for the specific language governing rights and limitations under 
+// the License.                                                             
+//                                                                          
+// The Original Code is eCos - Embedded Configurable Operating System,      
+// released September 30, 1998.                                             
+//                                                                          
+// The Initial Developer of the Original Code is Red Hat.                   
+// Portions created by Red Hat are                                          
+// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
+// All Rights Reserved.                                                     
+// -------------------------------------------                              
+//                                                                          
 //####COPYRIGHTEND####
 //=============================================================================
 //#####DESCRIPTIONBEGIN####
@@ -60,26 +62,26 @@
     !defined(CYG_KERNEL_DIAG_SERIAL2) && \
     !defined(CYG_KERNEL_DIAG_ROMART)
 
-# if defined(CYG_HAL_MN10300_STDEVAL1)
+# if defined(CYG_HAL_MN10300_AM31_STDEVAL1)
 
 #  if defined(CYG_HAL_STARTUP_RAM)
 
-#   if defined(CYG_HAL_USE_ROM_MONITOR_CYGMON)
+#   if defined(CYGSEM_HAL_USE_ROM_MONITOR_CygMon)
 
      // If loaded into RAM via CYGMON we diag via
      // serial 2 using GDB protocol
-    
+
 #    define CYG_KERNEL_DIAG_SERIAL2
 #    define CYG_KERNEL_DIAG_GDB
 
-#   elif defined(CYG_HAL_USE_ROM_MONITOR_SLOAD)
+#   elif defined(CYGSEM_HAL_USE_ROM_MONITOR_Sload)
 
      // If loaded into RAM via SLOAD we diag via
      // serial 1
     
 #    define CYG_KERNEL_DIAG_SERIAL1
     
-#   elif defined(CYG_HAL_USE_ROM_MONITOR_GDB_STUBS)
+#   elif defined(CYGSEM_HAL_USE_ROM_MONITOR_GDB_stubs)
 
      // If loaded into RAM via GDB STUB ROM we diag via
      // serial 1 using GDB protocol
@@ -87,7 +89,7 @@
 #    define CYG_KERNEL_DIAG_SERIAL1
 #    define CYG_KERNEL_DIAG_GDB
     
-#   endif // defined(CYG_HAL_USE_ROM_MONITOR_CYGMON)
+#   endif // defined(CYGSEM_HAL_USE_ROM_MONITOR_CygMon)
     
 #  elif defined(CYG_HAL_STARTUP_ROM)
 
@@ -97,7 +99,7 @@
     
 #  endif // defined(CYG_HAL_STARTUP_RAM)
     
-# endif // defined(CYG_HAL_MN10300_STDEVAL1)
+# endif // defined(CYG_HAL_MN10300_AM31_STDEVAL1)
 
 #endif // if ...
     
@@ -106,7 +108,7 @@
 
 #if defined(CYG_HAL_MN10300_STDEVAL1_ROMART) || defined(CYG_KERNEL_DIAG_ROMART)
 
-#ifdef CYG_HAL_MN10300_STDEVAL1
+#ifdef CYG_HAL_MN10300_AM31_STDEVAL1
 #define PROMICE_AILOC           0x40008000
 #endif
 
@@ -282,6 +284,9 @@ void hal_diag_read_char_serial1(char *c)
 
     *c = *tty_rx;
 
+    // We must ack the interrupt caused by that read to avoid
+    // confusing cygmon.
+    HAL_INTERRUPT_ACKNOWLEDGE( CYGNUM_HAL_INTERRUPT_SERIAL_1_RX );
 }
 
 #if defined(CYG_KERNEL_DIAG_SERIAL1)
@@ -295,7 +300,7 @@ void hal_diag_read_char_serial1(char *c)
 
 #endif
 
-#if defined(CYG_HAL_MN10300_STDEVAL1)
+#if defined(CYG_HAL_MN10300_AM31_STDEVAL1)
 
 void led(int x)
 {
@@ -332,7 +337,7 @@ void led(int x)
 
 void hal_diag_init_serial2(void)
 {
-#if !defined(CYG_HAL_USE_ROM_MONITOR_CYGMON)    
+#if !defined(CYGSEM_HAL_USE_ROM_MONITOR_CygMon)
 
     // 16 and 22 translate to 38400 baud.
     *TIMER2_BR = 16;
@@ -378,6 +383,12 @@ void hal_diag_read_char_serial2(char *c)
     while( (*tty_status & SIO2_LSTAT_RRDY) == 0 ) continue;
 
     *c = *tty_rx;
+
+#if !defined(CYGSEM_HAL_USE_ROM_MONITOR_CygMon)    
+    // We must ack the interrupt caused by that read to avoid
+    // confusing the stubs.
+    HAL_INTERRUPT_ACKNOWLEDGE( CYGNUM_HAL_INTERRUPT_SERIAL_2_RX );
+#endif
 }
 
 #if defined(CYG_KERNEL_DIAG_SERIAL2)
@@ -418,7 +429,16 @@ void hal_diag_write_char(char c)
         // later.
 
         CYG_INTERRUPT_STATE oldstate;
+        CYG_BYTE wdcr;
         HAL_DISABLE_INTERRUPTS(oldstate);
+
+        // Beacuse of problems with NT on the testfarm, we also have
+        // to disable the watchdog here. This only matters in the
+        // watchdog tests. And yes, this sends my irony meter off the
+        // scale too.
+        
+        HAL_READ_UINT8( 0x34004002, wdcr );
+        HAL_WRITE_UINT8( 0x34004002, wdcr&0x3F );
         
         while(1)
         {
@@ -443,39 +463,21 @@ void hal_diag_write_char(char c)
             hal_diag_write_char_serial(hex[(csum>>4)&0xF]);
             hal_diag_write_char_serial(hex[csum&0xF]);
 
-#if 0
+#if !defined(CYGSEM_HAL_USE_ROM_MONITOR_CygMon)
             {
                 char c1;
 
                 hal_diag_read_char_serial( &c1 );
 
-                // We must ack the interrupt caused by that read to avoid
-                // confusing the GDB stub ROM.
-                HAL_INTERRUPT_ACKNOWLEDGE( CYGNUM_HAL_INTERRUPT_EXTERNAL_2 );
-            
                 if( c1 == '+' ) break;
 
-                ai_writes("hal_diag_read_char_serial(");
-                ai_write_char(c1);
-                ai_writes(")\r\n");
-                ai_writes("retry\r\n");
-
-#if defined(CYG_HAL_USE_ROM_MONITOR) && defined(CYG_HAL_USE_ROM_MONITOR_CYGMON)
-                if( c1 == 3 )
-                {
-                    // Ctrl-C: breakpoint.
-//                HAL_BREAKPOINT(_breakinst);
-                    typedef void bpt_fn();
-                    bpt_fn *bfn = ((bpt_fn **)0x80000100)[61];
-
-                    bfn();
-                
-                    break;
-                }
-#endif
+                if( cyg_hal_is_break( &c1, 1 ) )
+                    cyg_hal_user_break( NULL );
 
             }
 #else
+            // When using Cygmon, the ack character is absorbed by cygmon's
+            // serial interrupt handler that is looking for Ctrl-Cs.
             break;
 #endif
         }
@@ -487,6 +489,7 @@ void hal_diag_write_char(char c)
         
         // And re-enable interrupts
         HAL_RESTORE_INTERRUPTS(oldstate);        
+        HAL_WRITE_UINT8( 0x34004002, wdcr );
         
     }
     
