@@ -6,25 +6,27 @@
 //
 //==========================================================================
 //####COPYRIGHTBEGIN####
-//
-// -------------------------------------------
-// The contents of this file are subject to the Cygnus eCos Public License
-// Version 1.0 (the "License"); you may not use this file except in
-// compliance with the License.  You may obtain a copy of the License at
-// http://sourceware.cygnus.com/ecos
-// 
-// Software distributed under the License is distributed on an "AS IS"
-// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the
-// License for the specific language governing rights and limitations under
-// the License.
-// 
-// The Original Code is eCos - Embedded Cygnus Operating System, released
-// September 30, 1998.
-// 
-// The Initial Developer of the Original Code is Cygnus.  Portions created
-// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
-// -------------------------------------------
-//
+//                                                                          
+// -------------------------------------------                              
+// The contents of this file are subject to the Red Hat eCos Public License 
+// Version 1.1 (the "License"); you may not use this file except in         
+// compliance with the License.  You may obtain a copy of the License at    
+// http://www.redhat.com/                                                   
+//                                                                          
+// Software distributed under the License is distributed on an "AS IS"      
+// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
+// License for the specific language governing rights and limitations under 
+// the License.                                                             
+//                                                                          
+// The Original Code is eCos - Embedded Configurable Operating System,      
+// released September 30, 1998.                                             
+//                                                                          
+// The Initial Developer of the Original Code is Red Hat.                   
+// Portions created by Red Hat are                                          
+// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
+// All Rights Reserved.                                                     
+// -------------------------------------------                              
+//                                                                          
 //####COPYRIGHTEND####
 //==========================================================================
 //#####DESCRIPTIONBEGIN####
@@ -73,7 +75,7 @@
 #include <cyg/infra/cyg_type.h>
 
 #include "cyg/hal/dbg-threads-api.h"
-#include "dbg-thread-syscall.h" 
+#include "cyg/hal/dbg-thread-syscall.h" 
 
 // -------------------------------------------------------------------------
 
@@ -120,15 +122,15 @@ static int dbg_thread_syscall_rmt(
       break ;
 #endif /* CYGDBG_KERNEL_DEBUG_GDB_THREAD_SUPPORT */      
     default :
-      return 0 ;  /* failure tue to non-implementation */
+      return 0 ;  /* failure due to non-implementation */
     }
 }
 
 // -------------------------------------------------------------------------
-// When Cygmon calls us on the TX39 It has its own value in GP. We need to
+// When Cygmon calls us on the MIPS It has its own value in GP. We need to
 // save that and set our own before proceeding.
 
-#ifdef CYG_HAL_TX39
+#ifdef CYGPKG_HAL_MIPS
 static int dbg_thread_syscall_rmt_1(
                        enum dbg_syscall_ids id,
                        union dbg_thread_syscall_parms * p
@@ -137,15 +139,15 @@ static int dbg_thread_syscall_rmt_1(
 
   register long gp_save;
   int r;
-  asm ( "move   %0,$28;"
-        ".extern _gp;"
-        "la     $gp,_gp;"
-        : "=r"(gp_save)
-      );
+  asm volatile ( "move   %0,$28;"
+                 ".extern _gp;"
+                 "la     $gp,_gp;"
+                 : "=r"(gp_save)
+                 );
 
   r = dbg_thread_syscall_rmt( id, p );
   
-  asm ( "move   $gp,%0;" :: "r"(gp_save) );
+  asm volatile ( "move   $gp,%0;" :: "r"(gp_save) );
 
   return r;
   
@@ -158,7 +160,7 @@ static int dbg_thread_syscall_rmt_1(
 
 #ifdef CYGDBG_KERNEL_DEBUG_GDB_THREAD_SUPPORT
 
-#ifdef CYG_HAL_SPARCLITE_SLEB
+#ifdef CYGPKG_HAL_SPARCLITE_SLEB
 # include <cyg/hal/hal_cygm.h>
 # ifdef CYG_HAL_USE_ROM_MONITOR_CYGMON
 // then we support talking to CygMon...
@@ -177,7 +179,7 @@ void patch_dbg_syscalls(void * vector)
 
 #ifdef CYGDBG_KERNEL_DEBUG_GDB_THREAD_SUPPORT
 
-#ifdef CYG_HAL_TX39
+#ifdef CYGPKG_HAL_MIPS
    f[DBG_SYSCALL_THREAD_VEC_NUM] = dbg_thread_syscall_rmt_1 ;
 #else   
    f[DBG_SYSCALL_THREAD_VEC_NUM] = dbg_thread_syscall_rmt ;
