@@ -6,25 +6,27 @@
 //
 //==========================================================================
 //####COPYRIGHTBEGIN####
-//
-// -------------------------------------------
-// The contents of this file are subject to the Cygnus eCos Public License
-// Version 1.0 (the "License"); you may not use this file except in
-// compliance with the License.  You may obtain a copy of the License at
-// http://sourceware.cygnus.com/ecos
-// 
-// Software distributed under the License is distributed on an "AS IS"
-// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the
-// License for the specific language governing rights and limitations under
-// the License.
-// 
-// The Original Code is eCos - Embedded Cygnus Operating System, released
-// September 30, 1998.
-// 
-// The Initial Developer of the Original Code is Cygnus.  Portions created
-// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
-// -------------------------------------------
-//
+//                                                                          
+// -------------------------------------------                              
+// The contents of this file are subject to the Red Hat eCos Public License 
+// Version 1.1 (the "License"); you may not use this file except in         
+// compliance with the License.  You may obtain a copy of the License at    
+// http://www.redhat.com/                                                   
+//                                                                          
+// Software distributed under the License is distributed on an "AS IS"      
+// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
+// License for the specific language governing rights and limitations under 
+// the License.                                                             
+//                                                                          
+// The Original Code is eCos - Embedded Configurable Operating System,      
+// released September 30, 1998.                                             
+//                                                                          
+// The Initial Developer of the Original Code is Red Hat.                   
+// Portions created by Red Hat are                                          
+// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
+// All Rights Reserved.                                                     
+// -------------------------------------------                              
+//                                                                          
 //####COPYRIGHTEND####
 //==========================================================================
 //#####DESCRIPTIONBEGIN####
@@ -99,16 +101,28 @@ externC int dbg_thread_capabilities(struct dbg_capabilities * cpb)
 
 static void dbg_make_threadref(Cyg_Thread *thread, threadref *ref )
 {
-    cyg_uint16 id = thread->get_unique_id();
+    // The following test tries to avoid accessing uninitialized pointers.
+    // This can happen if we take a breakpoint before the data is copied
+    // or the BSS zeroed. We currently assume that RAM will reset to zero
+    // or 0xff. If it is random, we have no hope.
+
+    if( (CYG_ADDRWORD)thread == 0 || (CYG_ADDRWORD)thread == 0xffffffff )                     
+    {
+        ((unsigned long *)ref)[0] = 0;
+        ((unsigned long *)ref)[1] = 0;
+    }
+    else
+    {
+        cyg_uint16 id = thread->get_unique_id();
 
 #if USE_ID
-    ((unsigned long *)ref)[0] = (unsigned long)thread;
-    ((unsigned long *)ref)[1] = (unsigned long)swap32(id);
+        ((unsigned long *)ref)[0] = (unsigned long)thread;
+        ((unsigned long *)ref)[1] = (unsigned long)swap32(id);
 #else    
-    ((unsigned long *)ref)[1] = (unsigned long)thread;
-    ((unsigned long *)ref)[0] = (unsigned long)id;
+        ((unsigned long *)ref)[1] = (unsigned long)thread;
+        ((unsigned long *)ref)[0] = (unsigned long)id;
 #endif
-    
+    }
 }
 
 static Cyg_Thread *dbg_get_thread( threadref *ref)
@@ -270,15 +284,24 @@ externC int dbg_threadinfo(
     switch( thread->get_state() & ~Cyg_Thread::SUSPENDED )
     {
     case Cyg_Thread::RUNNING:
-        s = "running";                  break;
+        if ( Cyg_Scheduler::get_current_thread() == thread ) {
+            s = "running";              break;
+        }
+        else if ( thread->get_state() & Cyg_Thread::SUSPENDED ) {
+            s = ""; sbp--; /*kill '+'*/ break;
+        }
+        else {
+            s = "ready";                break;
+        }
     case Cyg_Thread::SLEEPING:
         s = "sleeping";                 break;
+    case Cyg_Thread::COUNTSLEEP | Cyg_Thread::SLEEPING:
     case Cyg_Thread::COUNTSLEEP:
         s = "counted sleep";            break;
     case Cyg_Thread::CREATING:
-        s = "creating";                 break;
+        s = "creating"; sbp = statebuf; break;
     case Cyg_Thread::EXITED:
-        s = "exited";                   break;
+        s = "exited"; sbp = statebuf;   break;
     default:
         s = "unknown state";            break;
     }
