@@ -6,25 +6,27 @@
 //
 //==========================================================================
 //####COPYRIGHTBEGIN####
-//
-// -------------------------------------------
-// The contents of this file are subject to the Cygnus eCos Public License
-// Version 1.0 (the "License"); you may not use this file except in
-// compliance with the License.  You may obtain a copy of the License at
-// http://sourceware.cygnus.com/ecos
-// 
-// Software distributed under the License is distributed on an "AS IS"
-// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the
-// License for the specific language governing rights and limitations under
-// the License.
-// 
-// The Original Code is eCos - Embedded Cygnus Operating System, released
-// September 30, 1998.
-// 
-// The Initial Developer of the Original Code is Cygnus.  Portions created
-// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
-// -------------------------------------------
-//
+//                                                                          
+// -------------------------------------------                              
+// The contents of this file are subject to the Red Hat eCos Public License 
+// Version 1.1 (the "License"); you may not use this file except in         
+// compliance with the License.  You may obtain a copy of the License at    
+// http://www.redhat.com/                                                   
+//                                                                          
+// Software distributed under the License is distributed on an "AS IS"      
+// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
+// License for the specific language governing rights and limitations under 
+// the License.                                                             
+//                                                                          
+// The Original Code is eCos - Embedded Configurable Operating System,      
+// released September 30, 1998.                                             
+//                                                                          
+// The Initial Developer of the Original Code is Red Hat.                   
+// Portions created by Red Hat are                                          
+// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
+// All Rights Reserved.                                                     
+// -------------------------------------------                              
+//                                                                          
 //####COPYRIGHTEND####
 //==========================================================================
 //#####DESCRIPTIONBEGIN####
@@ -147,6 +149,8 @@ Cyg_Interrupt::call_pending_DSRs_inner(void)
 
         CYG_INSTRUMENT_INTR(CALL_DSR, intr->vector, 0);
         
+        CYG_ASSERT( intr->dsr != NULL , "No DSR defined");
+
         intr->dsr( intr->vector, 1, (CYG_ADDRWORD)intr->data );
     }
     
@@ -168,6 +172,8 @@ Cyg_Interrupt::call_pending_DSRs_inner(void)
         intr->dsr_count = 0;
         
         HAL_RESTORE_INTERRUPTS(old_intr);
+        
+        CYG_ASSERT( intr->dsr != NULL , "No DSR defined");
 
         intr->dsr( intr->vector, count, (CYG_ADDRWORD)intr->data );
         
@@ -183,16 +189,16 @@ cyg_interrupt_call_pending_DSRs(void)
     Cyg_Interrupt::call_pending_DSRs_inner();
 }
 
-// This function will be provided by HALs that fully implement
-// interrupt stack functionality
-externC void 
-hal_interrupt_stack_call_pending_DSRs(void)
-  __attribute__ ((weak, alias("cyg_interrupt_call_pending_DSRs")));
+//
+// Use HAL supported function to run through the DSRs, but executing using
+// the separate interrupt stack if available.  This function calls back
+// into this module via 'cyg_interrupt_call_pending_DSRs' above, to keep
+// the whole process as general as possible.
 
 void
 Cyg_Interrupt::call_pending_DSRs(void)
 {
-    hal_interrupt_stack_call_pending_DSRs();
+    HAL_INTERRUPT_STACK_CALL_PENDING_DSRS();
 }
 
 
@@ -322,14 +328,15 @@ cyg_uint32
 Cyg_Interrupt::chain_isr(cyg_vector vector, CYG_ADDRWORD data)
 {
     Cyg_Interrupt *p = *(Cyg_Interrupt **)data;
-
+    register cyg_uint32 isr_ret = 0;
+    
     CYG_INSTRUMENT_INTR(CHAIN_ISR, vector, 0);
 
     while( p != NULL )
     {
         if( p->vector == vector )
         {
-            register cyg_uint32 isr_ret = p->isr(vector, p->data);
+            isr_ret = p->isr(vector, p->data);
 
             if( isr_ret & Cyg_Interrupt::CALL_DSR ) p->post_dsr();
 
@@ -339,6 +346,17 @@ Cyg_Interrupt::chain_isr(cyg_vector vector, CYG_ADDRWORD data)
         p = p->next;
     }
 
+#ifdef HAL_DEFAULT_ISR
+    if( (isr_ret & Cyg_Interrupt::HANDLED) == 0 )
+    {
+        // If we finished the loop for some reason other than that an
+        // ISR has handled the interrupt, call any default ISR to either
+        // report the spurious interrupt, or do some other HAL level processing
+        // such as GDB interrupt detection etc.
+
+        HAL_DEFAULT_ISR( vector, NULL );
+    }
+#endif    
     return 0;
 }
 
