@@ -6,25 +6,27 @@
 //
 //=================================================================
 //####COPYRIGHTBEGIN####
-//
-// -------------------------------------------
-// The contents of this file are subject to the Cygnus eCos Public License
-// Version 1.0 (the "License"); you may not use this file except in
-// compliance with the License.  You may obtain a copy of the License at
-// http://sourceware.cygnus.com/ecos
-// 
-// Software distributed under the License is distributed on an "AS IS"
-// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the
-// License for the specific language governing rights and limitations under
-// the License.
-// 
-// The Original Code is eCos - Embedded Cygnus Operating System, released
-// September 30, 1998.
-// 
-// The Initial Developer of the Original Code is Cygnus.  Portions created
-// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
-// -------------------------------------------
-//
+//                                                                          
+// -------------------------------------------                              
+// The contents of this file are subject to the Red Hat eCos Public License 
+// Version 1.1 (the "License"); you may not use this file except in         
+// compliance with the License.  You may obtain a copy of the License at    
+// http://www.redhat.com/                                                   
+//                                                                          
+// Software distributed under the License is distributed on an "AS IS"      
+// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
+// License for the specific language governing rights and limitations under 
+// the License.                                                             
+//                                                                          
+// The Original Code is eCos - Embedded Configurable Operating System,      
+// released September 30, 1998.                                             
+//                                                                          
+// The Initial Developer of the Original Code is Red Hat.                   
+// Portions created by Red Hat are                                          
+// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
+// All Rights Reserved.                                                     
+// -------------------------------------------                              
+//                                                                          
 //####COPYRIGHTEND####
 //=================================================================
 //#####DESCRIPTIONBEGIN####
@@ -143,9 +145,14 @@ static void entry0( CYG_ADDRWORD data )
     cyg_exception_clear_handler(CYGNUM_HAL_EXCEPTION_MAX);
     cyg_exception_clear_handler(CYGNUM_HAL_EXCEPTION_MAX);
 
-#ifdef CYGPKG_HAL_I386_LINUX
+#if 0
+#elif defined(CYGPKG_HAL_POWERPC_SIM)
+    // The exception generated by the SIM is not recognized by GDB.
+    // PR 19945 workaround.
+    CYG_TEST_NA("Not applicable to PowerPC SIM");
+#elif defined(CYGPKG_HAL_I386_LINUX)
     // We can't catch segmentation violation exceptions on Linux.
-    CYG_TEST_PASS_FINISH("Except 1 OK");
+    CYG_TEST_NA("Not applicable to synthetic target");
 #endif
 
     for(n = CYGNUM_HAL_EXCEPTION_MIN; n <= CYGNUM_HAL_EXCEPTION_MAX; n++) {
@@ -164,7 +171,7 @@ static void entry0( CYG_ADDRWORD data )
     CYG_TEST_FAIL_FINISH("Couldn't cause exception");
 }
 
-#ifdef CYG_HAL_TX39_JMR3904
+#ifdef CYG_HAL_MIPS_TX39_JMR3904
 
 extern void __default_exception_vsr(void);
 
@@ -183,6 +190,9 @@ void except0_main( void )
 #ifdef CYGNUM_HAL_EXCEPTION_DATA_ACCESS
     HAL_VSR_SET_TO_ECOS_HANDLER( CYGNUM_HAL_EXCEPTION_DATA_ACCESS, NULL );
 #endif
+#ifdef CYGNUM_HAL_EXCEPTION_DATA_TLBMISS_ACCESS
+    HAL_VSR_SET_TO_ECOS_HANDLER( CYGNUM_HAL_EXCEPTION_DATA_TLBMISS_ACCESS, NULL );
+#endif
 #ifdef CYGNUM_HAL_EXCEPTION_DATA_UNALIGNED_ACCESS
     HAL_VSR_SET_TO_ECOS_HANDLER( CYGNUM_HAL_EXCEPTION_DATA_UNALIGNED_ACCESS, NULL );
 #endif
