@@ -6,25 +6,27 @@
 //
 //=================================================================
 //####COPYRIGHTBEGIN####
-//
-// -------------------------------------------
-// The contents of this file are subject to the Cygnus eCos Public License
-// Version 1.0 (the "License"); you may not use this file except in
-// compliance with the License.  You may obtain a copy of the License at
-// http://sourceware.cygnus.com/ecos
-// 
-// Software distributed under the License is distributed on an "AS IS"
-// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the
-// License for the specific language governing rights and limitations under
-// the License.
-// 
-// The Original Code is eCos - Embedded Cygnus Operating System, released
-// September 30, 1998.
-// 
-// The Initial Developer of the Original Code is Cygnus.  Portions created
-// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
-// -------------------------------------------
-//
+//                                                                          
+// -------------------------------------------                              
+// The contents of this file are subject to the Red Hat eCos Public License 
+// Version 1.1 (the "License"); you may not use this file except in         
+// compliance with the License.  You may obtain a copy of the License at    
+// http://www.redhat.com/                                                   
+//                                                                          
+// Software distributed under the License is distributed on an "AS IS"      
+// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
+// License for the specific language governing rights and limitations under 
+// the License.                                                             
+//                                                                          
+// The Original Code is eCos - Embedded Configurable Operating System,      
+// released September 30, 1998.                                             
+//                                                                          
+// The Initial Developer of the Original Code is Red Hat.                   
+// Portions created by Red Hat are                                          
+// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
+// All Rights Reserved.                                                     
+// -------------------------------------------                              
+//                                                                          
 //####COPYRIGHTEND####
 //=================================================================
 //#####DESCRIPTIONBEGIN####
@@ -153,14 +155,28 @@ test( CYG_ADDRWORD data )
     CYG_TEST_PASS_FAIL(ret == my_strlen(z),
                        "|%5d|%10s|%03d|%c|%o| test return code" );
 
+    // Check 3
+    ret = snprintf(y, 19, "print up to here >< and not this bit" );
+    my_strcpy(z, "print up to here >");
+    CYG_TEST_PASS_FAIL(my_strcmp(y,z) == 0, "simple snprintf test #1");
+    CYG_TEST_PASS_FAIL(ret == my_strlen(z),
+                       "simple snprintf test #1 return code" );
+    
+    // Check 4
+    ret = snprintf(y, 31, "print a bit of this number: %05d nyer", 1234);
+    my_strcpy(z, "print a bit of this number: 01");
+    CYG_TEST_PASS_FAIL(my_strcmp(y,z) == 0, "simple snprintf test #2");
+    CYG_TEST_PASS_FAIL(ret == my_strlen(z),
+                       "simple snprintf test #2 return code" );
+    
 #ifdef CYGSEM_LIBC_STDIO_PRINTF_FLOATING_POINT
 
     CYG_TEST_INFO("Starting floating point specific tests");
 
-    // Check 3
+    // Check 5
     ret = sprintf(y, "|%5f|%10s|%03d|%c|%+-5.2G|%010.3G|",
-                  2.0, "times", 6, '=', 12.0, -2.345e-6 );
-    my_strcpy(z, "|2.000000|     times|006|=|+12  |-02.34E-06|");
+                  2.0, "times", 6, '=', 12.0, -2.3451e-6 );
+    my_strcpy(z, "|2.000000|     times|006|=|+12  |-02.35E-06|");
 
     CYG_TEST_PASS_FAIL(my_strcmp(y,z) == 0,
                        "|%5f|%10s|%03d|%c|%+-5.2G|%010.3G| test");
@@ -169,6 +185,15 @@ test( CYG_ADDRWORD data )
                        "|%5f|%10s|%03d|%c|%+-5.2G|%010.3G| test "
                        "return code" );
 
+    // Check 6
+    ret = snprintf(y, 20, "bit of this: %g double", 6.431e8);
+    my_strcpy(z, "bit of this: 6.431e");
+    CYG_TEST_PASS_FAIL(my_strcmp(y,z) == 0,
+                       "snprintf double test #1");
+
+    CYG_TEST_PASS_FAIL(ret == my_strlen(z),
+                       "snprintf double test #1 return code");
+
 #endif // ifdef CYGSEM_LIBC_STDIO_PRINTF_FLOATING_POINT
 
     CYG_TEST_FINISH("Finished tests from testcase " __FILE__
